@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "easysession" "1.2.0"
+(define-package "easysession" "20251019.1621"
   "Persist and restore your sessions (desktop.el alternative)."
-  '((emacs "26.1"))
+  '((emacs "25.1"))
   :url "https://github.com/jamescherti/easysession.el"
-  :commit "bf2a989c8d990396784ae7e2a38ef9943465a967"
-  :revdesc "1.2.0-0-gbf2a989c8d99"
+  :commit "e825ae668de678f85f49d01a1a9cde830ff65deb"
+  :revdesc "e825ae668de6"
   :keywords '("convenience"))
